@@ -7,7 +7,7 @@
 #              in a BibTeX-style bibliographic database.
 # CREATED    : 1997/11/24, GPW (taken from Bib.pm)
 # MODIFIED   : 
-# VERSION    : $Id$
+# VERSION    : $Id: BibSort.pm 8423 2010-02-13 20:40:27Z ambs $
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights 
 #              reserved.
 # 
@@ -18,12 +18,11 @@
 
 package Text::BibTeX::BibSort;
 use strict;
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA);
 
 use Text::BibTeX::Structure;
 
 @ISA = qw(Text::BibTeX::StructuredEntry);
-$VERSION = 0.76_02;
 
 use Text::BibTeX qw(purify_string change_case);
 
@@ -147,8 +146,8 @@ sub sort_format_names
    my ($abbrev, $format, $name);
 
    $abbrev = ! ($self->structure->get_options ('namestyle') eq 'full');
-   $format =  Text::BibTeX::NameFormat->new ("vljf", $abbrev);
-   $name   = Text::BibTeX::Name->new;
+   $format = new Text::BibTeX::NameFormat ("vljf", $abbrev);
+   $name = new Text::BibTeX::Name;
 
    my (@snames, $i, $sname);
    @snames = $self->split ($field);
